==> portal-contribuinte-3.310.0.zip: BOOT-INF/classes/br/com/elotech/tributos/calculo/repository/load-cadastro-isencao-memoria.sql <==
select cadastrogeral.idkey as idCadastro,
       isencao.isencao,
       case
         when isencao.isentoimposto = 'S' then
          1
         else
          0
       end isentoimposto,
       case
	     when isencao.contabiliza = 'S' then
	      1
	     else
	      0
	   end contabilizaimposto,
       case
         when isencao.reducaoimposto = 'S' then
          1
         else
          0
       end reducaoimposto,
       isencao.valorreducaoimposto,
       case
         when isencao.isentotaxa = 'S' then
          1
         else
          0
       end isentotaxa,
       case
	     when isencao.contabilizataxa = 'S' then
	      1
	     else
	      0
	   end contabilizataxa,
       case
         when isencao.reducaotaxa = 'S' then
          1
         else
          0
       end reducaotaxa,
       isencao.valorreducaotaxa,
       case
         when isencao.isentocontribuicao = 'S' then
          1
         else
          0
       end isentocontribuicao,
       case
	     when isencao.contabilizacontribuicao = 'S' then
	      1
	     else
	      0
	   end contabilizacontribuicao,
       case
         when isencao.reducaocontribuicao = 'S' then
          1
         else
          0
       end reducaocontribuicao,
       isencao.valorreducaocontribuicao,
       case
         when isencao.isentornt = 'S' then
          1
         else
          0
       end isentoReceitasNaoTributaveis,
       case
	     when isencao.contabilizarnt = 'S' then
	      1
	     else
	      0
	   end contabilizaReceitasNaoTributaveis,
       case
         when isencao.reducaornt = 'S' then
          1
         else
          0
       end reducaoReceitasNaoTributaveis,
       isencao.valorreducaornt as valorReducaoReceitasNaoTrib
  from tribcadastrogeralmemoria cadastrogeral
  left join tribcadastroimobiliariomemoria cadastroimobiliario
    on cadastrogeral.cadastrogeral = cadastroimobiliario.cadastrogeral
   and cadastrogeral.tipocadastro = cadastroimobiliario.tipocadastro
   and cadastrogeral.idmemoriacadastro = cadastroimobiliario.idmemoriacadastro
  join tribcadastrogeralisencaomem cadastroisencao
    on cadastrogeral.tipocadastro = cadastroisencao.tipocadastro
   and cadastrogeral.cadastrogeral = cadastroisencao.cadastrogeral
   and cadastrogeral.idmemoriacadastro = cadastroisencao.idmemoriacadastro
  join tribisencao isencao
    on cadastroisencao.isencao = isencao.isencao
 where %s
 and cadastrogeral.exclusaologica = 'N'
 and isencao.inativo = 'N'
 and :exercicio between coalesce(cadastroisencao.anoisencao, :exercicio) and coalesce(cadastroisencao.fimisencao, :exercicio)

==> portal-contribuinte-4.106.0.zip: BOOT-INF/classes/br/com/elotech/tributos/calculo/repository/load-cadastro-isencao-memoria.sql <==
select cadastrogeral.idkey as idCadastro,
       isencao.isencao,
       case
         when isencao.isentoimposto = 'S' then
          1
         else
          0
       end isentoimposto,
       case
	     when isencao.contabiliza = 'S' then
	      1
	     else
	      0
	   end contabilizaimposto,
       case
         when isencao.reducaoimposto = 'S' then
          1
         else
          0
       end reducaoimposto,
       case when coalesce(cadastroisencao.valorreducaoimposto,0) > 0
          then cadastroisencao.valorreducaoimposto
          else isencao.valorreducaoimposto
       end valorreducaoimposto,
       case
         when isencao.isentotaxa = 'S' then
          1
         else
          0
       end isentotaxa,
       case
	     when isencao.contabilizataxa = 'S' then
	      1
	     else
	      0
	   end contabilizataxa,
       case
         when isencao.reducaotaxa = 'S' then
          1
         else
          0
       end reducaotaxa,
       case when coalesce(cadastroisencao.valorreducaotaxa,0) > 0
          then cadastroisencao.valorreducaotaxa
          else isencao.valorreducaotaxa
       end valorreducaotaxa,
       case
         when isencao.isentocontribuicao = 'S' then
          1
         else
          0
       end isentocontribuicao,
       case
	     when isencao.contabilizacontribuicao = 'S' then
	      1
	     else
	      0
	   end contabilizacontribuicao,
       case
         when isencao.reducaocontribuicao = 'S' then
          1
         else
          0
       end reducaocontribuicao,
       case when coalesce(cadastroisencao.valorreducaocontribuicao,0) > 0
          then cadastroisencao.valorreducaocontribuicao
          else isencao.valorreducaocontribuicao
       end valorreducaocontribuicao,
       case
         when isencao.isentornt = 'S' then
          1
         else
          0
       end isentoReceitasNaoTributaveis,
       case
	     when isencao.contabilizarnt = 'S' then
	      1
	     else
	      0
	   end contabilizaReceitasNaoTributaveis,
       case
         when isencao.reducaornt = 'S' then
          1
         else
          0
       end reducaoReceitasNaoTributaveis,
       case when coalesce(cadastroisencao.valorreducaornt,0) > 0
          then cadastroisencao.valorreducaornt
          else isencao.valorreducaornt
       end valorReducaoReceitasNaoTrib
  from tribcadastrogeralmemoria cadastrogeral
  left join tribcadastroimobiliariomemoria cadastroimobiliario
    on cadastrogeral.cadastrogeral = cadastroimobiliario.cadastrogeral
   and cadastrogeral.tipocadastro = cadastroimobiliario.tipocadastro
   and cadastrogeral.idmemoriacadastro = cadastroimobiliario.idmemoriacadastro
  join tribcadastrogeralisencaomem cadastroisencao
    on cadastrogeral.tipocadastro = cadastroisencao.tipocadastro
   and cadastrogeral.cadastrogeral = cadastroisencao.cadastrogeral
   and cadastrogeral.idmemoriacadastro = cadastroisencao.idmemoriacadastro
  join tribisencao isencao
    on cadastroisencao.isencao = isencao.isencao
 where %s
 and cadastrogeral.exclusaologica = 'N'
 and isencao.inativo = 'N'
 and :exercicio between coalesce(cadastroisencao.anoisencao, :exercicio) and coalesce(cadastroisencao.fimisencao, :exercicio)
